#
# spec file for package python-folium
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname folium
%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-folium%{psuffix}
Version:        0.19.4
Release:        1.1
Summary:        Make beautiful maps with Leafletjs and Python
License:        MIT
URL:            https://github.com/python-visualization/folium
# PyPI does not have an sdist, plus we need the tests from GitHub.
Source0:        https://github.com/python-visualization/folium/archive/v%{version}.tar.gz#/folium-%{version}-gh.tar.gz
BuildRequires:  %{python_module base > 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Jinja2 >= 2.9}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module branca >= 0.6.0}
BuildRequires:  %{python_module folium = %{version}}
BuildRequires:  %{python_module geopandas}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module xyzservices}
# No working chromedriver
#BuildRequires:  %%{python_module selenium}
#BuildRequires:  %%{python_module nbconvert}
%endif
Requires:       python-Jinja2 >= 2.9
Requires:       python-branca >= 0.6.0
Requires:       python-numpy
Requires:       python-requests
Requires:       python-xyzservices
BuildArch:      noarch
%python_subpackages

%description
Folium is a python library to make beautiful maps with Leafletsjs. Folium
builds on the data wrangling strengths of the Python ecosystem and the mapping
strengths of the Leaflet.js library. Manipulate your data in Python, then
visualize it in a Leaflet map via folium.

%prep
%autosetup -p1 -n folium-%{version}

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%install
%if !%{with test}
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# no working chromedriver for selenium
ignoretests="--ignore tests/selenium"
# requires network access
donttest="test_json_request or test_timedynamic_geo_json"
# also uses selenium
donttest="$donttest or test__repr_png_is_bytes or test_valid_png or test_valid_png_size"
# no proj database backend running
donttest="$donttest or test_choropleth_geopandas"
%pytest -k "not ($donttest)" $ignoretests
%endif

%if !%{with test}
%files %{python_files}
%doc CHANGES.txt README.rst
%license LICENSE.txt
%{python_sitelib}/folium/
%{python_sitelib}/folium-%{version}.dist-info/
%endif

%changelog
* Wed Feb 26 2025 Dirk Müller <dmueller@suse.com>
- update to 0.19.4:
  * Fix javascript template of TimelineSlider plugin
- update to 0.19.3:
  * Add DivIcon and CustomIcon as accepted type of Marker icon
  * Fix type hints after adding Branca type checking
  * HeatMap: document default gradient
* Sat Dec 21 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.19.2:
  * Remove empty values from the options
    (gh#python-visualization/folium#2049).
- Changes from version 0.19.1:
  * TileLayer: max_native_zoom cannot be null
    (gh#python-visualization/folium#2044).
- Changes from version 0.19.0:
  * Actually drop python 3.8
    (gh#python-visualization/folium#2031).
  * Add py.typed file for Mypy
    (gh#python-visualization/folium#2030).
  * Allow jscode in **kwargs throughout Folium
    (gh#python-visualization/folium#2029).
  * Implement the once method on Evented
    (gh#python-visualization/folium#2023).
  * Add OverlappingMarkerSpiderfier Plugin
    (gh#python-visualization/folium#2033).
- Add BuildRequires: python-base > 3.8 to make builds
  unresolvable, rather than failing, for Leap 15.X.
* Wed Jul 17 2024 Ben Greiner <code@bnavigator.de>
- Revert numpy < 2 pin. It's supported since 0.17
* Fri Jul 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2 for now.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 0.17.0:
  * Remove Python 3.7, add 3.12
  * Add layer control tree plugin
  * Add Timeline plugin
  * Add `Leaflet.encoded` plugin: Enable creating PolyLine and
    Polygon from encoded string
  * Add Evented base class
  * Update Map zoom_control variable to also allow string to set
    position
  * Add a custom container to the realtime plugin
  * Add custom Template class with tojavascript filter
  * Drop Bootstrap 3 but keep glyphicons
  * fix `__geo_interface__` styling
  * Fixes styling on tag filter button
  * repair max_zoom and max_native_zoom
  * Change `Map` lat&lon bound type annotations from int to float
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.16.0:
  * GeoJSON: option to keep layer highlighted when popup is open
  * Add leaflet-realtime plugin
  * Geocoder plugin: support other built-in providers
  * Add ability to set font size in plot
  * Geojson: allow null geometry objects
  * Realtime plugin: allow str for JsCode arg
* Sun Mar 17 2024 Atri Bhattacharya <badshah400@gmail.com>
- Disable for python3.9, python39-branca is not available.
* Wed Dec  6 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.15.1:
  * Use xyzservices instead of templates for tiles
    (gh#python-visualization/folium#1827).
  * Add TimeSliderChoropleth stroke colour/width/opacity argument
    (gh#python-visualization/folium#1838).
  * Improve docstring preview readibility in features.py
    (gh#python-visualization/folium#1833).
  * Fix streamlit-folium incompatibility (add layer to map with
    new class) (gh#python-visualization/folium#1834).
- Changes from version 0.15.0:
  * Drop support for Python 3.5 and 3.6
    (gh#python-visualization/folium#1729)
  * Remove deprecated Stamen tiles
    (gh#python-visualization/folium#1811)
  * Remove _env instance attributes
    (gh#python-visualization/folium#1817)
  * Use write_png from Branca, remove from Folium
    (gh#python-visualization/folium#1708)
  * Remove deprecated Map.choropleth method
    (gh#python-visualization/folium#1684)
  * Feature: Draggable layer control option
    (gh#python-visualization/folium#1760)
  * Feature: Add fit enabled overlays feature
    (gh#python-visualization/folium#1693)
  * Feature: Add type hints (gh#python-visualization/folium#1677)
  * Update jquery to v3.7.1 (gh#python-visualization/folium#1824)
  * Update leaflet.fullscreen plugin to 3.0.0
    (gh#python-visualization/folium#1818)
  * Allow Choropleth key_on to traverse through array
    (gh#python-visualization/folium#1772)
  * Support TagFilterButton in PolyLine, AntPath and GeoJson
    (gh#python-visualization/folium#1756)
  * Multiple instances of TimeSliderChoropleth on a single map
    (gh#python-visualization/folium#1749)
  * Make VectorGridProtobuf an overlay by default
    (gh#python-visualization/folium#1723)
  * Change internally where layers are added to the map
    (gh#python-visualization/folium#1690)
  * TimestampedWmsTileLayers inherit from MacroElement, not Layer
    (gh#python-visualization/folium#1696)
  * SideBySideLayers inherit from MacroElement, not Layer
    (gh#python-visualization/folium#1695)
  * Consolidate duplicate utility functions with Branca
    (gh#python-visualization/folium#1676)
  * Bug: Fix interaction between DualMap and Draw
    (gh#python-visualization/folium#1776)
  * Bug: Fix MeasureControl plugin for Leaflet>=1.8.0
    (gh#python-visualization/folium#1748)
  * Bug: Pin older version of leaflet side by side to fix
    SideBySideLayers plugin (gh#python-visualization/folium#1732)
  * Bug: Fix Map.show_in_browser() by adding local file prefix to
    url (gh#python-visualization/folium#1704)
- New Requires: python-xyzservices.
* Mon Feb 27 2023 Matej Cepl <mcepl@suse.com>
- Remove stupid copy&paste error.
* Sat Feb 25 2023 Matej Cepl <mcepl@suse.com>
- Split package into multibuild to avoid a build cycle
  (bsc#1207791).
* Sat Dec 31 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.14
  [#]# Breaking changes
  * Use keyword arguments as CSS properties in FloatImage
    (@Conengmo #1668)
  * Upgrade Leaflet 1.6.0 to 1.9.3, set default font size
    (@Conengmo #1660)
  * Upgrade Bootstrap 3.2.0 to 5.2.2 (@Conengmo #1650)
  [#]# New plugins
  * Add GroupedLayerControl plugin (@chansooligans #1592)
  * Add SideBySide plugin (@fralc #1292)
  * Add TagFilterButton plugin (@Waffleboy #1343)
  [#]# Major improvements
  * Add optional Jenks Natural Breaks Optimization to Choropleth
    (@pmains #1634)
  * Add Map.show_in_browser() method (@Conengmo #1651)
  * Accept TileProvider objects from the xyzservices package
    (@martinfleis #1498)
  * Add support for Vega-Lite v4 and v5 (@wd60622 #1525)
  * Upgrade Font Awesome 4.6.3 to 6.2.0 (@Sujithkumardola #1637)
  [#]# Minor improvements
  * Allow cql_filter argument in WmsTileLayer (@Conengmo #1673)
  * Silently allow lowerCamelCase for vector path options
    (@Conengmo #1672)
  * Allow html popups and templating in ClickForMarker (@Conengmo
    [#1666])
  * Add show_geometry_on_click argument to Draw plugin (@Conengmo
    [#1657])
  * Automatically join string and numeric key_on values for
    Choropleth (@alessioarena #1193)
  * Add speed_slider argument to TimeStampedGeoJson (@gokyori
    [#1279])
  * Add gradient option to vector path options (@nocturnalAndroid
    [#1433])
  * Add initial timestamp argument to TimeSliderChoropleth
    (@jjbenes #1435)
  * Allow passing TileLayer to Map (@Conengmo #1624)
  * Use fullscreen window in Map._to_png() (@Conengmo #1656)
  * Expose webdriver argument in Map._to_png() (@WooilJeong #1620)
  * Export the map only in Map._to_png() (@Vayel #1197)
  [#]# Bug fixes
  * Fix LayerControl visibility on multiple renders (@Conengmo
    [#1674])
  * Fix the new TagFilterButton plugin, it's not a Layer (@Conengmo
    [#1671])
  * Fix TopoJson object path lookup (@Conengmo #1665)
  * Fix Choropleth when `bins` is a list of integers (@Conengmo
    [#1664])
  * Fix attribution links in Notebooks opening within iframe
    (@Conengmo #1655)
  * Fix empty geojson failing when using style_function (@agussman
    [#1213])
  * Fix Marker location validation for numpy array (@Conengmo
    [#1647])
  * Fix date sorting in TimeSliderChoropleth (@Ade-StapleHill
    [#1503])
  * Fix unescaped backticks in Popup (@Conengmo #1642)
  * Fix `map.get_bounds()` when using GeometryCollection
    (@amrutha1098 #1633)
  * Fix ClickForLatLng not imported in __init__ (@amrutha1098
    [#1627])
* Mon Oct 31 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.13.0:
  * Lazy popup: only load content on click
    (gh#python-visualization/folium#1511).
  * Add Leaflet.VectorGrid plugin: VectorGridProtobuf
    (gh#python-visualization/folium#1576).
  * Add blur parameter to HeatMapWithTime plugin
    (gh#python-visualization/folium#1529).
  * New ClickForLatLng class: click to save lat/lon to clipboard
    (gh#python-visualization/folium#1530).
  * Add width parameter to css for FloatImage
    (gh#python-visualization/folium#1570).
  * Add support for tooltips in TimestampedGeoJson objects
    (gh#python-visualization/folium#1472).
  * Expose GeoJson's web retrieval to its own function
    (gh#python-visualization/folium#1458).
  * Restore allowing simple Popup in GeoJson
    (gh#python-visualization/folium#1528).
  * Fix test failure with recent branca change on map ids
    (gh#python-visualization/folium#1556).
  * Documentation updates.
* Mon Feb 14 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.12.1.post1:
  * Fix version issue (gh#python-visualization/folium#1536).
* Sun Feb 21 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.12.1
  * Minor bugfix on the version number in the source distribution
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29)
- Drop tests.tar.gz
  * 0.12.1 is not released as sdist on PyPI. Use the GitHub archive
    directly and tell setuptools_scm to use an explicit version
* Sun Jan 10 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.12.0:
  * GeoJson add zoom_on_click option, default False
    (gh#python-visualization/folium#1349).
  * Add Geocoder plugin (gh#python-visualization/folium#1323).
  * Replace githack.com CDN with jsdelivr.com
    (gh#python-visualization/folium#1337).
  * Add SemiCircle plugin (gh#python-visualization/folium#1238).
  * Move hardcoded JS CDN links to class variables
    (gh#python-visualization/folium#1312,
    gh#python-visualization/folium#1416).
  * Treat data uris as valid
    (gh#python-visualization/folium#1428).
  * Add GeoJson marker option
    (gh#python-visualization/folium#957).
  * Bug fixes:
  - Fix TimeSliderChoropleth breaking when using layer control
    (gh#python-visualization/folium#1380).
  - Fix GeoJson data loading
    (gh#python-visualization/folium#1353).
  - Fix heatmap weights/intensity
    (gh#python-visualization/folium#1354,
    gh#python-visualization/folium#1282).
  - Fix multiple GeoJsonPopup 'name_getter' JS SyntaxError
    (gh#python-visualization/folium#1347).
  - Fix TimestampedWmsTileLayers layer control
    (gh#python-visualization/folium#1319).
  * API changes
  - Remove deprecated Mapbox and Cloudmade tilesets
    (gh#python-visualization/folium#1339).
- Use source from PyPI since Github source leads to incorrect
  version determination for egg-info dir.
- Use _service file to download tests from Github since the PyPI
  sources don't have this dir; exclude the selenium dir in tests
  since we don't run the selenium test suite to avoid dependency
  bloat (which requires a running chromium browser).
- Additional BuildRequires: python-setuptools-scm required to
  determine correct version during build.
- Update required version of branca to 0.4.2.
- Drop patch
  0001-assert-bounds-within-reasonable-machine-precision.patch:
  incorporated upstream.
* Mon Jan  4 2021 Benjamin Greiner <code@bnavigator.de>
- Add 0001-assert-bounds-within-reasonable-machine-precision.patch
  gh#python-visualization/folium#1432 fixes i586 test suite fail
* Sat Jun  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
